@@ -3,6 +3,8 @@ pub use swc_ecma_ast as ast;
 pub use swc_ecma_codegen as codegen;
 #[cfg(feature = "dep_graph")]
 pub use swc_ecma_dep_graph as dep_graph;
+#[cfg(feature = "minifier")]
+pub use swc_ecma_minifier as minifier;
 #[cfg(feature = "parser")]
 pub use swc_ecma_parser as parser;
 #[cfg(feature = "preset_env")]
